@@ -231,8 +231,6 @@ public:
     control->SetFlex(true,true);
 
     hpanel->Add(Lum::AspectRatio::Create(control,640,480,true,true));
-    hpanel->AddSpace();
-    hpanel->Add(Lum::Button::Create(L"_Klick!",knips,Lum::Button::typeDefault,false,true));
 
     led=new Lum::LED();
     led->SetModel(knipsing);
